@@ -12,6 +12,7 @@
 """
 
 from subprocess import check_output, Popen
+from lib389 import DirSrv
 from lib389.idm.user import UserAccounts
 import pytest
 from lib389.tasks import *
@@ -24,6 +25,9 @@ from lib389.topologies import topology_st
 from lib389.paths import Paths
 from lib389.idm.directorymanager import DirectoryManager
 from lib389.config import LDBMConfig
+from lib389.dseldif import DSEldif
+from lib389.rootdse import RootDSE
+
 
 pytestmark = pytest.mark.tier0
 
@@ -35,6 +39,7 @@ log = logging.getLogger(__name__)
 USER1_DN = 'uid=user1,' + DEFAULT_SUFFIX
 USER2_DN = 'uid=user2,' + DEFAULT_SUFFIX
 USER3_DN = 'uid=user3,' + DEFAULT_SUFFIX
+USER4_DN = 'uid=user4,' + DEFAULT_SUFFIX
 
 ROOTDSE_DEF_ATTR_LIST = ('namingContexts',
                          'supportedLDAPVersion',
@@ -53,11 +58,11 @@ def import_example_ldif(topology_st):
 
     ldif = '%s/dirsrv/data/Example.ldif' % topology_st.standalone.get_data_dir()
     import_ldif = topology_st.standalone.get_ldif_dir() + "/Example.ldif"
-    shutil.copyfile(ldif, import_ldif)
+    shutil.copy(ldif, import_ldif)
 
-    r = ImportTask(topology_st.standalone)
-    r.import_suffix_from_ldif(ldiffile=import_ldif, suffix=DEFAULT_SUFFIX)
-    r.wait()
+    import_task = ImportTask(topology_st.standalone)
+    import_task.import_suffix_from_ldif(ldiffile=import_ldif, suffix=DEFAULT_SUFFIX)
+    import_task.wait()
 
 
 @pytest.fixture(params=ROOTDSE_DEF_ATTR_LIST)
@@ -77,7 +82,7 @@ def rootdse_attr(topology_st, request):
     try:
         topology_st.standalone.modify_s("", mod)
     except ldap.LDAPError as e:
-        log.fatal('Failed to add attr: error (%s)' % (e.message['desc']))
+        log.fatal('Failed to add attr: error (%s)' % (e.args[0]['desc']))
         assert False
 
     def fin():
@@ -87,7 +92,7 @@ def rootdse_attr(topology_st, request):
         try:
             topology_st.standalone.modify_s("", mod)
         except ldap.LDAPError as e:
-            log.fatal('Failed to delete attr: error (%s)' % (e.message['desc']))
+            log.fatal('Failed to delete attr: error (%s)' % (e.args[0]['desc']))
             assert False
 
     request.addfinalizer(fin)
@@ -133,7 +138,7 @@ def test_basic_ops(topology_st, import_example_ldif):
                                              'uid': 'user1',
                                              'userpassword': 'password'})))
     except ldap.LDAPError as e:
-        log.error('Failed to add test user' + USER1_DN + ': error ' + e.message['desc'])
+        log.error('Failed to add test user' + USER1_DN + ': error ' + e.args[0]['desc'])
         assert False
 
     try:
@@ -144,7 +149,7 @@ def test_basic_ops(topology_st, import_example_ldif):
                                              'uid': 'user2',
                                              'userpassword': 'password'})))
     except ldap.LDAPError as e:
-        log.error('Failed to add test user' + USER2_DN + ': error ' + e.message['desc'])
+        log.error('Failed to add test user' + USER2_DN + ': error ' + e.args[0]['desc'])
         assert False
 
     try:
@@ -155,7 +160,7 @@ def test_basic_ops(topology_st, import_example_ldif):
                                              'uid': 'user3',
                                              'userpassword': 'password'})))
     except ldap.LDAPError as e:
-        log.error('Failed to add test user' + USER3_DN + ': error ' + e.message['desc'])
+        log.error('Failed to add test user' + USER3_DN + ': error ' + e.args[0]['desc'])
         assert False
 
     #
@@ -165,21 +170,21 @@ def test_basic_ops(topology_st, import_example_ldif):
         topology_st.standalone.modify_s(USER1_DN, [(ldap.MOD_ADD, 'description',
                                                     b'New description')])
     except ldap.LDAPError as e:
-        log.error('Failed to add description: error ' + e.message['desc'])
+        log.error('Failed to add description: error ' + e.args[0]['desc'])
         assert False
 
     try:
         topology_st.standalone.modify_s(USER1_DN, [(ldap.MOD_REPLACE, 'description',
                                                     b'Modified description')])
     except ldap.LDAPError as e:
-        log.error('Failed to modify description: error ' + e.message['desc'])
+        log.error('Failed to modify description: error ' + e.args[0]['desc'])
         assert False
 
     try:
         topology_st.standalone.modify_s(USER1_DN, [(ldap.MOD_DELETE, 'description',
                                                     None)])
     except ldap.LDAPError as e:
-        log.error('Failed to delete description: error ' + e.message['desc'])
+        log.error('Failed to delete description: error ' + e.args[0]['desc'])
         assert False
 
     #
@@ -188,20 +193,20 @@ def test_basic_ops(topology_st, import_example_ldif):
     try:
         topology_st.standalone.rename_s(USER1_DN, USER1_NEWDN, delold=1)
     except ldap.LDAPError as e:
-        log.error('Failed to modrdn user1: error ' + e.message['desc'])
+        log.error('Failed to modrdn user1: error ' + e.args[0]['desc'])
         assert False
 
     try:
         topology_st.standalone.rename_s(USER2_DN, USER2_NEWDN, delold=0)
     except ldap.LDAPError as e:
-        log.error('Failed to modrdn user2: error ' + e.message['desc'])
+        log.error('Failed to modrdn user2: error ' + e.args[0]['desc'])
         assert False  # Modrdn - New superior
 
     try:
         topology_st.standalone.rename_s(USER3_DN, USER3_NEWDN,
                                         newsuperior=NEW_SUPERIOR, delold=1)
     except ldap.LDAPError as e:
-        log.error('Failed to modrdn(new superior) user3: error ' + e.message['desc'])
+        log.error('Failed to modrdn(new superior) user3: error ' + e.args[0]['desc'])
         assert False
     #
     # Deletes
@@ -209,19 +214,19 @@ def test_basic_ops(topology_st, import_example_ldif):
     try:
         topology_st.standalone.delete_s(USER1_RDN_DN)
     except ldap.LDAPError as e:
-        log.error('Failed to delete test entry1: ' + e.message['desc'])
+        log.error('Failed to delete test entry1: ' + e.args[0]['desc'])
         assert False
 
     try:
         topology_st.standalone.delete_s(USER2_RDN_DN)
     except ldap.LDAPError as e:
-        log.error('Failed to delete test entry2: ' + e.message['desc'])
+        log.error('Failed to delete test entry2: ' + e.args[0]['desc'])
         assert False
 
     try:
         topology_st.standalone.delete_s(USER3_RDN_DN)
     except ldap.LDAPError as e:
-        log.error('Failed to delete test entry3: ' + e.message['desc'])
+        log.error('Failed to delete test entry3: ' + e.args[0]['desc'])
         assert False
     log.info('test_basic_ops: PASSED')
 
@@ -265,18 +270,21 @@ def test_basic_import_export(topology_st, import_example_ldif):
 
     # Online
     log.info("Importing LDIF online...")
-    r = ImportTask(topology_st.standalone)
-    r.import_suffix_from_ldif(ldiffile=import_ldif, suffix=DEFAULT_SUFFIX)
+    import_task = ImportTask(topology_st.standalone)
+    import_task.import_suffix_from_ldif(ldiffile=import_ldif, suffix=DEFAULT_SUFFIX)
+
+    # Wait a bit till the task is created and available for searching
+    time.sleep(0.5)
 
     # Good as place as any to quick test the task has some expected attributes
     if ds_is_newer('1.4.1.2'):
-        assert r.present('nstaskcreated')
-    assert r.present('nstasklog')
-    assert r.present('nstaskcurrentitem')
-    assert r.present('nstasktotalitems')
-    assert r.present('ttl')
+        assert import_task.present('nstaskcreated')
+    assert import_task.present('nstasklog')
+    assert import_task.present('nstaskcurrentitem')
+    assert import_task.present('nstasktotalitems')
+    assert import_task.present('ttl')
 
-    r.wait()
+    import_task.wait()
 
     # Offline
     log.info("Importing LDIF offline...")
@@ -294,9 +302,9 @@ def test_basic_import_export(topology_st, import_example_ldif):
     log.info("Exporting LDIF online...")
     export_ldif = ldif_dir + '/export.ldif'
 
-    r = ExportTask(topology_st.standalone)
-    r.export_suffix_to_ldif(ldiffile=export_ldif, suffix=DEFAULT_SUFFIX)
-    r.wait()
+    export_task = ExportTask(topology_st.standalone)
+    export_task.export_suffix_to_ldif(ldiffile=export_ldif, suffix=DEFAULT_SUFFIX)
+    export_task.wait()
 
     # Offline export
     log.info("Exporting LDIF offline...")
@@ -316,9 +324,9 @@ def test_basic_import_export(topology_st, import_example_ldif):
     import_ldif = topology_st.standalone.get_ldif_dir() + "/Example.ldif"
     shutil.copyfile(ldif, import_ldif)
 
-    r = ImportTask(topology_st.standalone)
-    r.import_suffix_from_ldif(ldiffile=import_ldif, suffix=DEFAULT_SUFFIX)
-    r.wait()
+    import_task = ImportTask(topology_st.standalone)
+    import_task.import_suffix_from_ldif(ldiffile=import_ldif, suffix=DEFAULT_SUFFIX)
+    import_task.wait()
 
     log.info('test_basic_import_export: PASSED')
 
@@ -440,8 +448,8 @@ def test_basic_acl(topology_st, import_example_ldif):
                                              'uid': 'user1',
                                              'userpassword': PASSWORD})))
     except ldap.LDAPError as e:
-        log.fatal('test_basic_acl: Failed to add test user ' + USER1_DN
-                  + ': error ' + e.message['desc'])
+        log.fatal('test_basic_acl: Failed to add test user ' + USER1_DN +
+                  ': error ' + e.args[0]['desc'])
         assert False
 
     try:
@@ -452,8 +460,8 @@ def test_basic_acl(topology_st, import_example_ldif):
                                              'uid': 'user2',
                                              'userpassword': PASSWORD})))
     except ldap.LDAPError as e:
-        log.fatal('test_basic_acl: Failed to add test user ' + USER1_DN
-                  + ': error ' + e.message['desc'])
+        log.fatal('test_basic_acl: Failed to add test user ' + USER1_DN +
+                  ': error ' + e.args[0]['desc'])
         assert False
 
     #
@@ -463,7 +471,7 @@ def test_basic_acl(topology_st, import_example_ldif):
     try:
         topology_st.standalone.modify_s(DEFAULT_SUFFIX, [(ldap.MOD_ADD, 'aci', DENY_ACI)])
     except ldap.LDAPError as e:
-        log.fatal('test_basic_acl: Failed to add DENY ACI: error ' + e.message['desc'])
+        log.fatal('test_basic_acl: Failed to add DENY ACI: error ' + e.args[0]['desc'])
         assert False
 
     #
@@ -472,7 +480,7 @@ def test_basic_acl(topology_st, import_example_ldif):
     try:
         topology_st.standalone.simple_bind_s(USER1_DN, PASSWORD)
     except ldap.LDAPError as e:
-        log.fatal('test_basic_acl: Failed to bind as user1, error: ' + e.message['desc'])
+        log.fatal('test_basic_acl: Failed to bind as user1, error: ' + e.args[0]['desc'])
         assert False
 
     try:
@@ -483,14 +491,14 @@ def test_basic_acl(topology_st, import_example_ldif):
             log.fatal('test_basic_acl: User1 was incorrectly able to search the suffix!')
             assert False
     except ldap.LDAPError as e:
-        log.fatal('test_basic_acl: Search suffix failed(as user1): ' + e.message['desc'])
+        log.fatal('test_basic_acl: Search suffix failed(as user1): ' + e.args[0]['desc'])
         assert False
 
     # Now try user2...  Also check that userpassword is stripped out
     try:
         topology_st.standalone.simple_bind_s(USER2_DN, PASSWORD)
     except ldap.LDAPError as e:
-        log.fatal('test_basic_acl: Failed to bind as user2, error: ' + e.message['desc'])
+        log.fatal('test_basic_acl: Failed to bind as user2, error: ' + e.args[0]['desc'])
         assert False
 
     try:
@@ -505,7 +513,7 @@ def test_basic_acl(topology_st, import_example_ldif):
             log.fatal('test_basic_acl: User2 was incorrectly able to see userpassword')
             assert False
     except ldap.LDAPError as e:
-        log.fatal('test_basic_acl: Search for user1 failed(as user2): ' + e.message['desc'])
+        log.fatal('test_basic_acl: Search for user1 failed(as user2): ' + e.args[0]['desc'])
         assert False
 
     # Make sure RootDN can also search (this also resets the bind dn to the
@@ -513,7 +521,7 @@ def test_basic_acl(topology_st, import_example_ldif):
     try:
         topology_st.standalone.simple_bind_s(DN_DM, PW_DM)
     except ldap.LDAPError as e:
-        log.fatal('test_basic_acl: Failed to bind as ROotDN, error: ' + e.message['desc'])
+        log.fatal('test_basic_acl: Failed to bind as ROotDN, error: ' + e.args[0]['desc'])
         assert False
 
     try:
@@ -524,7 +532,7 @@ def test_basic_acl(topology_st, import_example_ldif):
             log.fatal('test_basic_acl: Root DN incorrectly not able to search the suffix')
             assert False
     except ldap.LDAPError as e:
-        log.fatal('test_basic_acl: Search for user1 failed(as user2): ' + e.message['desc'])
+        log.fatal('test_basic_acl: Search for user1 failed(as user2): ' + e.args[0]['desc'])
         assert False
 
     #
@@ -533,19 +541,19 @@ def test_basic_acl(topology_st, import_example_ldif):
     try:
         topology_st.standalone.modify_s(DEFAULT_SUFFIX, [(ldap.MOD_DELETE, 'aci', DENY_ACI)])
     except ldap.LDAPError as e:
-        log.fatal('test_basic_acl: Failed to delete DENY ACI: error ' + e.message['desc'])
+        log.fatal('test_basic_acl: Failed to delete DENY ACI: error ' + e.args[0]['desc'])
         assert False
 
     try:
         topology_st.standalone.delete_s(USER1_DN)
     except ldap.LDAPError as e:
-        log.fatal('test_basic_acl: Failed to delete test entry1: ' + e.message['desc'])
+        log.fatal('test_basic_acl: Failed to delete test entry1: ' + e.args[0]['desc'])
         assert False
 
     try:
         topology_st.standalone.delete_s(USER2_DN)
     except ldap.LDAPError as e:
-        log.fatal('test_basic_acl: Failed to delete test entry2: ' + e.message['desc'])
+        log.fatal('test_basic_acl: Failed to delete test entry2: ' + e.args[0]['desc'])
         assert False
 
     log.info('test_basic_acl: PASSED')
@@ -597,12 +605,59 @@ def test_basic_searches(topology_st, import_example_ldif):
                           (search_filter, len(entries), search_result))
                 assert False
         except ldap.LDAPError as e:
-            log.fatal('Search failed: ' + e.message['desc'])
+            log.fatal('Search failed: ' + e.args[0]['desc'])
             assert False
 
     log.info('test_basic_searches: PASSED')
 
 
+@pytest.fixture(scope="module")
+def add_test_entry(topology_st, request):
+    # Add test entry
+    topology_st.standalone.add_s(Entry((USER4_DN,
+                                        {'objectclass': "top extensibleObject".split(),
+                                         'cn': 'user1', 'uid': 'user1'})))
+
+
+search_params = [(['1.1'], 'cn', False),
+                 (['1.1', 'cn'], 'cn', True),
+                 (['+'], 'nsUniqueId', True),
+                 (['*'], 'cn', True),
+                 (['cn'], 'cn', True)]
+@pytest.mark.skipif(ds_is_older("1.4.2.0"), reason="Not implemented")
+@pytest.mark.parametrize("attrs, attr, present", search_params)
+def test_search_req_attrs(topology_st, add_test_entry, attrs, attr, present):
+    """Test requested attributes in search operations.
+
+    :id: 426a59ff-49b8-4a70-b377-0c0634a29b6e
+    :parametrized: yes
+    :setup: Standalone instance
+    :steps:
+         1. Test "1.1" does not return any attributes.
+         2. Test "1.1" is ignored if there are other requested attributes
+         3. Test "+" returns all operational attributes
+         4. Test "*" returns all attributes
+         5. Test requested attributes
+
+    :expectedresults:
+         1. Success
+         2. Success
+         3. Success
+         4. Success
+         5. Success
+    """
+
+    log.info("Testing attrs: {} attr: {} present: {}".format(attrs, attr, present))
+    entry = topology_st.standalone.search_s(USER4_DN,
+                                            ldap.SCOPE_BASE,
+                                            'objectclass=top',
+                                            attrs)
+    if present:
+        assert entry[0].hasAttr(attr)
+    else:
+        assert not entry[0].hasAttr(attr)
+
+
 def test_basic_referrals(topology_st, import_example_ldif):
     """Test LDAP server in referral mode.
 
@@ -638,7 +693,7 @@ def test_basic_referrals(topology_st, import_example_ldif):
                                           'nsslapd-referral',
                                           b'ldap://localhost.localdomain:389/o%3dnetscaperoot')])
     except ldap.LDAPError as e:
-        log.fatal('test_basic_referrals: Failed to set referral: error ' + e.message['desc'])
+        log.fatal('test_basic_referrals: Failed to set referral: error ' + e.args[0]['desc'])
         assert False
 
     try:
@@ -646,7 +701,7 @@ def test_basic_referrals(topology_st, import_example_ldif):
                                                          'nsslapd-state', b'Referral')])
     except ldap.LDAPError as e:
         log.fatal('test_basic_referrals: Failed to set backend state: error '
-                  + e.message['desc'])
+                  + e.args[0]['desc'])
         assert False
 
     #
@@ -658,7 +713,7 @@ def test_basic_referrals(topology_st, import_example_ldif):
     except ldap.REFERRAL:
         pass
     except ldap.LDAPError as e:
-        log.fatal('test_basic_referrals: Search failed: ' + e.message['desc'])
+        log.fatal('test_basic_referrals: Search failed: ' + e.args[0]['desc'])
         assert False
 
     #
@@ -674,7 +729,7 @@ def test_basic_referrals(topology_st, import_example_ldif):
                                                          'nsslapd-state', b'Backend')])
     except ldap.LDAPError as e:
         log.fatal('test_basic_referrals: Failed to set backend state: error '
-                  + e.message['desc'])
+                  + e.args[0]['desc'])
         assert False
 
     try:
@@ -682,7 +737,7 @@ def test_basic_referrals(topology_st, import_example_ldif):
                                                          'nsslapd-referral', None)])
     except ldap.LDAPError as e:
         log.fatal('test_basic_referrals: Failed to delete referral: error '
-                  + e.message['desc'])
+                  + e.args[0]['desc'])
         assert False
     topology_st.standalone.set_option(ldap.OPT_REFERRALS, 1)
 
@@ -747,8 +802,8 @@ def test_basic_systemctl(topology_st, import_example_ldif):
     log.info('Attempting to start the server with broken dse.ldif...')
     try:
         topology_st.standalone.start()
-    except:
-        log.info('Server failed to start as expected')
+    except Exception as e:
+        log.info('Server failed to start as expected: ' + str(e))
     log.info('Check the status...')
     assert (not topology_st.standalone.status())
     log.info('Server failed to start as expected')
@@ -853,7 +908,7 @@ def test_def_rootdse_attr(topology_st, import_example_ldif, rootdse_attr_name):
     """Tests that operational attributes are not returned by default in rootDSE searches
 
     :id: 4fee33cc-4019-4c27-89e8-998e6c770dc0
-
+    :parametrized: yes
     :setup: Standalone instance
 
     :steps:
@@ -873,7 +928,7 @@ def test_def_rootdse_attr(topology_st, import_example_ldif, rootdse_attr_name):
         assert not entry.hasAttr(rootdse_attr_name)
 
     except ldap.LDAPError as e:
-        log.fatal('Search failed, error: ' + e.message['desc'])
+        log.fatal('Search failed, error: ' + e.args[0]['desc'])
         assert False
 
 
@@ -881,7 +936,7 @@ def test_mod_def_rootdse_attr(topology_st, import_example_ldif, rootdse_attr):
     """Tests that operational attributes are returned by default in rootDSE searches after config modification
 
    :id: c7831e04-f458-4e23-83c7-b6f66109f639
-
+   :parametrized: yes
    :setup: Standalone instance and we are using rootdse_attr fixture which
 adds nsslapd-return-default-opattr attr with value of one operation attribute.
 
@@ -900,7 +955,7 @@ adds nsslapd-return-default-opattr attr with value of one operation attribute.
         assert entry.hasAttr(rootdse_attr)
 
     except ldap.LDAPError as e:
-        log.fatal('Search failed, error: ' + e.message['desc'])
+        log.fatal('Search failed, error: ' + e.args[0]['desc'])
         assert False
 
 
@@ -1221,6 +1276,109 @@ sample_entries = yes
     request.addfinalizer(fin)
 
 
+@pytest.fixture(scope="module")
+def dscreate_ldapi_instance(request):
+    template_file = "/tmp/dssetup.inf"
+    longname_serverid = "test_longname_deadbeef_deadbeef_deadbeef_deadbeef_deadbeef"
+    template_text = """[general]
+config_version = 2
+# This invalid hostname ...
+full_machine_name = localhost.localdomain
+# Means we absolutely require this.
+strict_host_checking = False
+# In tests, we can be run in containers, NEVER trust
+# that systemd is there, or functional in any capacity
+systemd = False
+
+[slapd]
+instance_name = %s
+root_dn = cn=directory manager
+root_password = someLongPassword_123
+# We do not have access to high ports in containers,
+# so default to something higher.
+port = 38999
+secure_port = 63699
+
+
+[backend-userroot]
+suffix = dc=example,dc=com
+sample_entries = yes
+""" % longname_serverid
+
+    with open(template_file, "w") as template_fd:
+        template_fd.write(template_text)
+
+    # Unset PYTHONPATH to avoid mixing old CLI tools and new lib389
+    tmp_env = os.environ
+    if "PYTHONPATH" in tmp_env:
+        del tmp_env["PYTHONPATH"]
+    try:
+        subprocess.check_call([
+            'dscreate',
+            'from-file',
+            template_file
+        ], env=tmp_env)
+    except subprocess.CalledProcessError as e:
+        log.fatal("dscreate failed!  Error ({}) {}".format(e.returncode, e.output))
+        assert False
+
+    inst = DirSrv(verbose=True, external_log=log)
+    dse_ldif = DSEldif(inst,
+                       serverid=longname_serverid)
+
+    socket_path = dse_ldif.get("cn=config", "nsslapd-ldapifilepath")
+    inst.local_simple_allocate(
+       serverid=longname_serverid,
+       ldapuri=f"ldapi://{socket_path[0].replace('/', '%2f')}",
+       password="someLongPassword_123"
+    )
+    inst.ldapi_enabled = 'on'
+    inst.ldapi_socket = socket_path
+    inst.ldapi_autobind = 'off'
+    try:
+        inst.open()
+    except:
+        log.fatal("Failed to connect via ldapi to %s instance" % longname_serverid)
+        os.remove(template_file)
+        try:
+            subprocess.check_call(['dsctl', longname_serverid, 'remove', '--do-it'])
+        except subprocess.CalledProcessError as e:
+            log.fatal("Failed to remove test instance  Error ({}) {}".format(e.returncode, e.output))
+
+    def fin():
+        os.remove(template_file)
+        try:
+            subprocess.check_call(['dsctl', longname_serverid, 'remove', '--do-it'])
+        except subprocess.CalledProcessError as e:
+            log.fatal("Failed to remove test instance  Error ({}) {}".format(e.returncode, e.output))
+
+    request.addfinalizer(fin)
+
+    return inst
+
+
+@pytest.mark.skipif(not get_user_is_root() or not default_paths.perl_enabled or ds_is_older('1.4.2.0'),
+                    reason="This test is only required with new admin cli, and requires root.")
+@pytest.mark.bz1748016
+@pytest.mark.ds50581
+def test_dscreate_longname(dscreate_ldapi_instance):
+    """Test that an instance with a long name can
+    handle ldapi connection using a long socket name
+
+    :id: 5d72d955-aff8-4741-8c9a-32c1c707cf1f
+    :setup: None
+    :steps:
+        1. create an instance with a long serverId name, that open a ldapi connection
+        2. Connect with ldapi, that hit 50581 and crash the instance
+    :expectedresults:
+        1. Should succeeds
+        2. Should succeeds
+    """
+
+    root_dse = RootDSE(dscreate_ldapi_instance)
+    log.info(root_dse.get_supported_ctrls())
+
+
 if __name__ == '__main__':
     # Run isolated
     # -s for DEBUG mode
