@@ -89,7 +89,7 @@ vlv_AddIndexEntry(Slapi_PBlock *pb __attribute__((unused)),
     slapi_rwlock_wrlock(be->vlvSearchList_lock);
     parent = vlvSearch_finddn((struct vlvSearch *)be->vlvSearchList, &parentdn);
     if (parent != NULL) {
-        char *name = slapi_entry_attr_get_charptr(entryBefore, type_vlvName);
+        char *name = (char *)slapi_entry_attr_get_ref(entryBefore, type_vlvName);
         if (vlvSearch_findname(parent, name)) {
             /* The vlvindex is already in the vlvSearchList. Skip adding it. */
             slapi_log_err(SLAPI_LOG_BACKLDBM,
@@ -101,7 +101,6 @@ vlv_AddIndexEntry(Slapi_PBlock *pb __attribute__((unused)),
             vlvIndex_init(newVlvIndex, be, parent, entryBefore);
             vlvSearch_addIndex(parent, newVlvIndex);
         }
-        slapi_ch_free_string(&name);
     }
     slapi_rwlock_unlock(be->vlvSearchList_lock);
     slapi_sdn_done(&parentdn);
@@ -257,11 +256,10 @@ vlv_SearchIndexEntry(Slapi_PBlock *pb __attribute__((unused)),
                      char *returntext __attribute__((unused)),
                      void *arg)
 {
-    char *name = slapi_entry_attr_get_charptr(entryBefore, type_vlvName);
+    char *name = (char *)slapi_entry_attr_get_ref(entryBefore, type_vlvName);
     backend *be = ((ldbm_instance *)arg)->inst_be;
     if (name != NULL) {
         struct vlvIndex *p = vlv_find_searchname(name, be); /* lock list */
-        slapi_ch_free((void **)&name);
         if (p != NULL) {
             if (vlvIndex_enabled(p)) {
                 slapi_entry_attr_set_charptr(entryBefore, type_vlvEnabled, "1");
@@ -1149,15 +1147,14 @@ vlv_search_build_candidate_list(Slapi_PBlock *pb, const Slapi_DN *base, int *vlv
     slapi_pblock_get(pb, SLAPI_SEARCH_STRFILTER, &fstr);
     slapi_rwlock_rdlock(be->vlvSearchList_lock);
     if ((pi = vlv_find_search(be, base, scope, fstr, sort_control)) == NULL) {
-        unsigned int opnote = SLAPI_OP_NOTE_UNINDEXED;
         int pr_idx = -1;
         Connection *pb_conn = NULL;
         Operation *pb_op = NULL;
 
         slapi_pblock_get(pb, SLAPI_PAGED_RESULTS_INDEX, &pr_idx);
         slapi_rwlock_unlock(be->vlvSearchList_lock);
-        slapi_pblock_set(pb, SLAPI_OPERATION_NOTES, &opnote);
 
+        slapi_pblock_set_flag_operation_notes(pb, SLAPI_OP_NOTE_UNINDEXED);
         slapi_pblock_get(pb, SLAPI_OPERATION, &pb_op);
         slapi_pblock_get(pb, SLAPI_CONNECTION, &pb_conn);
 
