@@ -206,6 +206,7 @@ connection_cleanup(Connection *conn)
     conn->c_isreplication_session = 0;
     slapi_ch_free((void **)&conn->cin_addr);
     slapi_ch_free((void **)&conn->cin_destaddr);
+    slapi_ch_free((void **)&conn->cin_addr_aclip);
     slapi_ch_free_string(&conn->c_ipaddr);
     if (conn->c_domain != NULL) {
         ber_bvecfree(conn->c_domain);
@@ -275,6 +276,8 @@ connection_reset(Connection *conn, int ns, PRNetAddr *from, int fromLen __attrib
 {
     char *pTmp = is_SSL ? "SSL " : "";
     char *str_ip = NULL, *str_destip;
+    char buf_ldapi[sizeof(from->local.path) + 1] = {0};
+    char buf_destldapi[sizeof(from->local.path) + 1] = {0};
     char buf_ip[INET6_ADDRSTRLEN + 1] = {0};
     char buf_destip[INET6_ADDRSTRLEN + 1] = {0};
     char *str_unknown = "unknown";
@@ -296,18 +299,18 @@ connection_reset(Connection *conn, int ns, PRNetAddr *from, int fromLen __attrib
     slapi_ch_free((void **)&conn->cin_addr); /* just to be conservative */
     if (from->raw.family == PR_AF_LOCAL) {   /* ldapi */
         conn->cin_addr = (PRNetAddr *)slapi_ch_malloc(sizeof(PRNetAddr));
-        PL_strncpyz(buf_ip, from->local.path, sizeof(from->local.path));
+        PL_strncpyz(buf_ldapi, from->local.path, sizeof(from->local.path));
         memcpy(conn->cin_addr, from, sizeof(PRNetAddr));
-        if (!buf_ip[0]) {
+        if (!buf_ldapi[0]) {
             PR_GetPeerName(conn->c_prfd, from);
-            PL_strncpyz(buf_ip, from->local.path, sizeof(from->local.path));
+            PL_strncpyz(buf_ldapi, from->local.path, sizeof(from->local.path));
             memcpy(conn->cin_addr, from, sizeof(PRNetAddr));
-            if (!buf_ip[0]) {
+            if (!buf_ldapi[0]) {
                 /* Cannot derive local address, need something for logging */
-                PL_strncpyz(buf_ip, "local", sizeof(buf_ip));
+                PL_strncpyz(buf_ldapi, "local", sizeof(buf_ldapi));
             }
         }
-        str_ip = buf_ip;
+        str_ip = buf_ldapi;
     } else if (((from->ipv6.ip.pr_s6_addr32[0] != 0) || /* from contains non zeros */
                 (from->ipv6.ip.pr_s6_addr32[1] != 0) ||
                 (from->ipv6.ip.pr_s6_addr32[2] != 0) ||
@@ -362,21 +365,24 @@ connection_reset(Connection *conn, int ns, PRNetAddr *from, int fromLen __attrib
         memset(conn->cin_destaddr, 0, sizeof(PRNetAddr));
         if (PR_GetSockName(conn->c_prfd, conn->cin_destaddr) == 0) {
             if (conn->cin_destaddr->raw.family == PR_AF_LOCAL) { /* ldapi */
-                PL_strncpyz(buf_destip, conn->cin_destaddr->local.path,
+                PL_strncpyz(buf_destldapi, conn->cin_destaddr->local.path,
                             sizeof(conn->cin_destaddr->local.path));
-                if (!buf_destip[0]) {
-                    PL_strncpyz(buf_destip, "unknown local file", sizeof(buf_destip));
+                if (!buf_destldapi[0]) {
+                    PL_strncpyz(buf_destldapi, "unknown local file", sizeof(buf_destldapi));
                 }
-            } else if (PR_IsNetAddrType(conn->cin_destaddr, PR_IpAddrV4Mapped)) {
-                PRNetAddr v4destaddr = {{0}};
-                v4destaddr.inet.family = PR_AF_INET;
-                v4destaddr.inet.ip = conn->cin_destaddr->ipv6.ip.pr_s6_addr32[3];
-                PR_NetAddrToString(&v4destaddr, buf_destip, sizeof(buf_destip));
+                str_destip = buf_destldapi;
             } else {
-                PR_NetAddrToString(conn->cin_destaddr, buf_destip, sizeof(buf_destip));
+                if (PR_IsNetAddrType(conn->cin_destaddr, PR_IpAddrV4Mapped)) {
+                    PRNetAddr v4destaddr = {{0}};
+                    v4destaddr.inet.family = PR_AF_INET;
+                    v4destaddr.inet.ip = conn->cin_destaddr->ipv6.ip.pr_s6_addr32[3];
+                    PR_NetAddrToString(&v4destaddr, buf_destip, sizeof (buf_destip));
+                } else {
+                    PR_NetAddrToString(conn->cin_destaddr, buf_destip, sizeof (buf_destip));
+                }
+                buf_destip[sizeof (buf_destip) - 1] = '\0';
+                str_destip = buf_destip;
             }
-            buf_destip[sizeof(buf_destip) - 1] = '\0';
-            str_destip = buf_destip;
         } else {
             str_destip = str_unknown;
         }
@@ -403,6 +409,7 @@ connection_reset(Connection *conn, int ns, PRNetAddr *from, int fromLen __attrib
             str_destip = str_unknown;
         }
     }
+    slapi_ch_free((void **)&conn->cin_addr_aclip);
 
     if (!in_referral_mode) {
         /* create a sasl connection */
@@ -706,12 +713,6 @@ connection_release_nolock_ext(Connection *conn, int release_only)
     } else {
         conn->c_refcnt--;
 
-        if (!release_only && (conn->c_refcnt == 1) && (conn->c_flags & CONN_FLAG_CLOSING)) {
-            /* if refcnt == 1 usually means only the active connection list has a ref */
-            /* refcnt == 0 means conntable just dropped the last ref */
-            ns_connection_post_io_or_closing(conn);
-        }
-
         return 0;
     }
 }
@@ -1346,10 +1347,6 @@ connection_make_readable_nolock(Connection *conn)
     conn->c_gettingber = 0;
     slapi_log_err(SLAPI_LOG_CONNS, "connection_make_readable_nolock", "making readable conn %" PRIu64 " fd=%d\n",
                   conn->c_connid, conn->c_sd);
-    if (!(conn->c_flags & CONN_FLAG_CLOSING)) {
-        /* if the connection is closing, try the close in connection_release_nolock */
-        ns_connection_post_io_or_closing(conn);
-    }
 }
 
 /*
@@ -1491,10 +1488,8 @@ connection_threadmain()
     int replication_connection = 0; /* If this connection is from a replication supplier, we want to ensure that operation processing is serialized */
     int doshutdown = 0;
     int maxthreads = 0;
-    int enable_nunc_stans = 0;
     long bypasspollcnt = 0;
 
-    enable_nunc_stans = config_get_enable_nunc_stans();
 #if defined(hpux)
     /* Arrange to ignore SIGPIPE signals. */
     SIGNAL(SIGPIPE, SIG_IGN);
@@ -1571,12 +1566,15 @@ connection_threadmain()
                      */
                     pb_conn->c_anonlimits_set = 1;
                 }
-                pthread_mutex_unlock(&(pb_conn->c_mutex));
 
+                /* must hold c_mutex so that it synchronizes the IO layer push
+                 * with a potential pending sasl bind that is registering the IO layer
+                 */
                 if (connection_call_io_layer_callbacks(pb_conn)) {
                     slapi_log_err(SLAPI_LOG_ERR, "connection_threadmain",
                                   "Could not add/remove IO layers from connection\n");
                 }
+                pthread_mutex_unlock(&(pb_conn->c_mutex));
                 break;
             default:
                 break;
@@ -1716,13 +1714,7 @@ connection_threadmain()
                 /* once the connection is readable, another thread may access conn,
                  * so need locking from here on */
                 signal_listner();
-                /* with nunc-stans, I see an enormous amount of time spent in the poll() in
-                 * connection_read_operation() when the below code is enabled - not sure why
-                 * nunc-stans makes such a huge difference - for now, just disable this code
-                 * when using nunc-stans - it is supposed to be an optimization but turns out
-                 * to not be the opposite with nunc-stans
-                 */
-            } else if (!enable_nunc_stans) { /* more data in conn - just put back on work_q - bypass poll */
+            } else { /* more data in conn - just put back on work_q - bypass poll */
                 bypasspollcnt++;
                 pthread_mutex_lock(&(conn->c_mutex));
                 /* don't do this if it would put us over the max threads per conn */
@@ -2319,9 +2311,6 @@ disconnect_server_nomutex_ext(Connection *conn, PRUint64 opconnid, int opid, PRE
                 }
             }
         }
-        if (schedule_closure_job) {
-            ns_connection_post_io_or_closing(conn); /* make sure event loop wakes up and closes this conn */
-        }
 
     } else {
         slapi_log_err(SLAPI_LOG_CONNS, "disconnect_server_nomutex_ext", "Not setting conn %d to be disconnected: %s\n",
