@@ -89,6 +89,7 @@ void attr_syntax_write_lock(void);
 void attr_syntax_unlock_read(void);
 void attr_syntax_unlock_write(void);
 int attr_syntax_exists(const char *attr_name);
+int32_t attr_syntax_exist_by_name_nolock(char *name);
 void attr_syntax_delete(struct asyntaxinfo *asip, PRUint32 schema_flags);
 #define SLAPI_SYNTAXLENGTH_NONE (-1) /* for syntaxlength parameter */
 int attr_syntax_create(const char *attr_oid, char *const *attr_names, const char *attr_desc, const char *attr_superior, const char *mr_equality, const char *mr_ordering, const char *mr_substring, schemaext *extensions, const char *attr_syntax, int syntaxlength, unsigned long flags, struct asyntaxinfo **asip);
@@ -574,6 +575,9 @@ int config_get_enable_nunc_stans(void);
 int config_set_enable_nunc_stans(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_extract_pem(const char *attrname, char *value, char *errorbuf, int apply);
 
+int32_t config_set_verify_filter_schema(const char *attrname, char *value, char *errorbuf, int apply);
+Slapi_Filter_Policy config_get_verify_filter_schema(void);
+
 PLHashNumber hashNocaseString(const void *key);
 PRIntn hashNocaseCompare(const void *v1, const void *v2);
 int config_get_ignore_time_skew(void);
@@ -791,7 +795,7 @@ int slapi_log_access(int level, char *fmt, ...)
     ;
 #endif
 int slapd_log_audit(char *buffer, int buf_len, int sourcelog);
-int slapd_log_audit_internal(char *buffer, int buf_len, int state);
+int slapd_log_audit_internal(char *buffer, int buf_len, int *state);
 int slapd_log_auditfail(char *buffer, int buf_len);
 int slapd_log_auditfail_internal(char *buffer, int buf_len);
 void log_access_flush(void);
@@ -873,7 +877,8 @@ void freepmods(LDAPMod **pmods);
 /*
  * monitor.c
  */
-int monitor_info(Slapi_PBlock *pb, Slapi_Entry *entryBefore, Slapi_Entry *entryAfter, int *returncode, char *returntext, void *arg);
+int32_t monitor_info(Slapi_PBlock *pb, Slapi_Entry *entryBefore, Slapi_Entry *entryAfter, int *returncode, char *returntext, void *arg);
+int32_t monitor_disk_info(Slapi_PBlock *pb, Slapi_Entry *entryBefore, Slapi_Entry *entryAfter, int *returncode, char *returntext, void *arg);
 char *slapd_get_version_value(void);
 
 
@@ -887,6 +892,10 @@ void operation_free(Slapi_Operation **op, Connection *conn);
 int slapi_op_abandoned(Slapi_PBlock *pb);
 void operation_out_of_disk_space(void);
 int get_operation_object_type(void);
+void *operation_get_target_entry(Slapi_Operation *op);
+void operation_set_target_entry(Slapi_Operation *op, void *target_void);
+u_int32_t operation_get_target_entry_id(Slapi_Operation *op);
+void operation_set_target_entry_id(Slapi_Operation *op, u_int32_t target_entry_id);
 Slapi_DN *operation_get_target_spec(Slapi_Operation *op);
 void operation_set_target_spec(Slapi_Operation *op, const Slapi_DN *target_spec);
 void operation_set_target_spec_str(Slapi_Operation *op, const char *target_spec);
@@ -1485,9 +1494,8 @@ void handle_closed_connection(Connection *);
 void slapd_do_nothing(int);
 #endif
 void slapd_wait4child(int);
-
-void ns_handle_pr_read_ready(struct ns_job_t *job);
-void ns_connection_post_io_or_closing(Connection *conn);
+void disk_mon_get_dirs(char ***list);
+int32_t disk_get_info(char *dir, uint64_t *total_space, uint64_t *avail_space, uint64_t *used_space);
 
 /*
  * main.c
