@@ -13,9 +13,13 @@ import {
     Modal,
     Icon,
     Form,
+    Row,
+    Col,
+    ControlLabel,
     Button,
     noop,
     TreeView,
+    Radio,
     Spinner
 } from "patternfly-react";
 import PropTypes from "prop-types";
@@ -41,7 +45,11 @@ export class Database extends React.Component {
             showSuffixModal: false,
             createSuffix: "",
             createBeName: "",
-            createRootNode: false,
+            createSuffixEntry: false,
+            createSampleEntries: false,
+            noSuffixInit: true,
+            disableTree: false,
+
             // DB config
             globalDBConfig: {},
             configUpdated: 0,
@@ -67,6 +75,7 @@ export class Database extends React.Component {
         this.removeNotification = this.removeNotification.bind(this);
         this.addNotification = this.addNotification.bind(this);
         this.handleChange = this.handleChange.bind(this);
+        this.handleRadioChange = this.handleRadioChange.bind(this);
         this.loadGlobalConfig = this.loadGlobalConfig.bind(this);
         this.loadLDIFs = this.loadLDIFs.bind(this);
         this.loadBackups = this.loadBackups.bind(this);
@@ -75,7 +84,6 @@ export class Database extends React.Component {
         // Suffix
         this.showSuffixModal = this.showSuffixModal.bind(this);
         this.closeSuffixModal = this.closeSuffixModal.bind(this);
-        this.handleChange = this.handleChange.bind(this);
         this.createSuffix = this.createSuffix.bind(this);
         this.loadSuffix = this.loadSuffix.bind(this);
         this.loadSuffixConfig = this.loadSuffixConfig.bind(this);
@@ -94,6 +102,7 @@ export class Database extends React.Component {
 
         // Other
         this.loadSuffixTree = this.loadSuffixTree.bind(this);
+        this.enableTree = this.enableTree.bind(this);
     }
 
     componentWillMount () {
@@ -203,8 +212,8 @@ export class Database extends React.Component {
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
                 .done(content => {
-                    const config = JSON.parse(content);
-                    const availableOids = config.items.filter((el) => !this.state.chainingConfig.oidList.includes(el));
+                    let config = JSON.parse(content);
+                    let availableOids = config.items.filter((el) => !this.state.chainingConfig.oidList.includes(el));
                     this.setState((prevState) => (
                         {
                             chainingConfig: {
@@ -295,15 +304,19 @@ export class Database extends React.Component {
                     const config = JSON.parse(content);
                     let availableComps = config.attrs.nspossiblechainingcomponents;
                     let compList = [];
+                    let oidList = [];
                     if ('nsactivechainingcomponents' in config.attrs) {
                         availableComps = config.attrs.nspossiblechainingcomponents.filter((el) => !config.attrs.nsactivechainingcomponents.includes(el));
                         compList = config.attrs.nsactivechainingcomponents;
                     }
+                    if ('nstransmittedcontrols' in config.attrs) {
+                        oidList = config.attrs.nstransmittedcontrols;
+                    }
                     this.setState(() => (
                         {
                             chainingConfig: {
                                 ...this.state.chainingConfig,
-                                oidList: config.attrs.nstransmittedcontrols,
+                                oidList: oidList,
                                 compList: compList,
                                 availableComps: availableComps
                             }
@@ -441,6 +454,13 @@ export class Database extends React.Component {
     }
 
     selectNode(selectedNode) {
+        if (selectedNode.selected) {
+            return;
+        }
+        this.setState({
+            disableTree: true // Disable the tree to allow node to be fully loaded
+        });
+
         if (selectedNode.id == "dbconfig" ||
             selectedNode.id == "chaining-config" ||
             selectedNode.id == "backups") {
@@ -536,15 +556,40 @@ export class Database extends React.Component {
         for (let el of elements) {
             el.setAttribute('title', el.innerText);
         }
+        this.setState({
+            disableTree: false
+        });
     }
 
     showSuffixModal () {
         this.setState({
             showSuffixModal: true,
+            createSuffixEntry: false,
+            createSampleEntries: false,
+            noSuffixInit: true,
             errObj: {},
         });
     }
 
+    handleRadioChange(e) {
+        // Handle the create suffix init option radio button group
+        let noInit = false;
+        let addSuffix = false;
+        let addSample = false;
+        if (e.target.id == "noSuffixInit") {
+            noInit = true;
+        } else if (e.target.id == "createSuffixEntry") {
+            addSuffix = true;
+        } else { // createSampleEntries
+            addSample = true;
+        }
+        this.setState({
+            noSuffixInit: noInit,
+            createSuffixEntry: addSuffix,
+            createSampleEntries: addSample
+        });
+    }
+
     handleChange(e) {
         const value = e.target.type === 'checkbox' ? e.target.checked : e.target.value;
         let valueErr = false;
@@ -570,7 +615,7 @@ export class Database extends React.Component {
         let errors = false;
         let missingArgs = {
             createSuffix: false,
-            createBeName: false
+            createBeName: false,
         };
 
         if (this.state.createSuffix == "") {
@@ -601,9 +646,12 @@ export class Database extends React.Component {
             "dsconf", "-j", "ldapi://%2fvar%2frun%2fslapd-" + this.props.serverId + ".socket",
             "backend", "create", "--be-name", this.state.createBeName, '--suffix', this.state.createSuffix,
         ];
-        if (this.state.createSampleEntries == true) {
+        if (this.state.createSampleEntries) {
             cmd.push('--create-entries');
         }
+        if (this.state.createSuffixEntry) {
+            cmd.push('--create-suffix');
+        }
 
         log_cmd("createSuffix", "Create a new backend", cmd);
         cockpit
@@ -616,6 +664,7 @@ export class Database extends React.Component {
                     );
                     // Refresh tree
                     this.loadSuffixTree(false);
+                    this.loadSuffixList();
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
@@ -942,8 +991,38 @@ export class Database extends React.Component {
                                                             suffixLoading: false
                                                         });
                                                     });
+                                        })
+                                        .fail(err => {
+                                            let errMsg = JSON.parse(err);
+                                            this.addNotification(
+                                                "error",
+                                                `Error attribute encryption for ${suffix} - ${errMsg.desc}`
+                                            );
+                                            this.setState({
+                                                suffixLoading: false
+                                            });
                                         });
+                            })
+                            .fail(err => {
+                                let errMsg = JSON.parse(err);
+                                this.addNotification(
+                                    "error",
+                                    `Error loading VLV indexes for ${suffix} - ${errMsg.desc}`
+                                );
+                                this.setState({
+                                    suffixLoading: false
+                                });
                             });
+                })
+                .fail(err => {
+                    let errMsg = JSON.parse(err);
+                    this.addNotification(
+                        "error",
+                        `Error loading config for ${suffix} - ${errMsg.desc}`
+                    );
+                    this.setState({
+                        suffixLoading: false
+                    });
                 });
     }
 
@@ -1013,9 +1092,20 @@ export class Database extends React.Component {
                 });
     }
 
+    enableTree () {
+        this.setState({
+            disableTree: false
+        });
+    }
+
     render() {
         const { nodes } = this.state;
         let db_element = "";
+        let disabled = "tree-view-container";
+        if (this.state.disableTree) {
+            disabled = "tree-view-container ds-disabled";
+        }
+
         if (this.state.loaded) {
             if (this.state.node_name == DB_CONFIG || this.state.node_name == "") {
                 db_element =
@@ -1024,6 +1114,7 @@ export class Database extends React.Component {
                         addNotification={this.addNotification}
                         reload={this.loadGlobalConfig}
                         data={this.state.globalDBConfig}
+                        enableTree={this.enableTree}
                         key={this.state.configUpdated}
                     />;
             } else if (this.state.node_name == CHAINING_CONFIG) {
@@ -1033,6 +1124,7 @@ export class Database extends React.Component {
                         addNotification={this.addNotification}
                         reload={this.loadChainingConfig}
                         data={this.state.chainingConfig}
+                        enableTree={this.enableTree}
                         key={this.state.chainingUpdated}
                     />;
             } else if (this.state.node_name == BACKUP_CONFIG) {
@@ -1043,6 +1135,7 @@ export class Database extends React.Component {
                         backups={this.state.BackupRows}
                         suffixes={this.state.suffixList}
                         ldifs={this.state.LDIFRows}
+                        enableTree={this.enableTree}
                         reload={this.loadBackups}
                     />;
             } else if (this.state.node_name != "") {
@@ -1050,10 +1143,9 @@ export class Database extends React.Component {
                 if (this.state.dbtype == "suffix" || this.state.dbtype == "subsuffix") {
                     if (this.state.suffixLoading) {
                         db_element =
-                            <div className="ds-loading-spinner ds-center">
-                                <p />
+                            <div className="ds-margin-top ds-loading-spinner ds-center">
                                 <h4>Loading suffix configuration for <b>{this.state.node_text} ...</b></h4>
-                                <Spinner loading size="md" />
+                                <Spinner className="ds-margin-top-lg" loading size="md" />
                             </div>;
                     } else {
                         db_element =
@@ -1073,6 +1165,7 @@ export class Database extends React.Component {
                                 dbtype={this.state.dbtype}
                                 data={this.state[this.state.node_text]}
                                 attrs={this.state.attributes}
+                                enableTree={this.enableTree}
                                 key={this.state.node_text}
                             />;
                     }
@@ -1080,10 +1173,9 @@ export class Database extends React.Component {
                     // Chaining
                     if (this.state.chainingLoading) {
                         db_element =
-                            <div className="ds-loading-spinner ds-center">
-                                <p />
+                            <div className="ds-margin-top ds-loading-spinner ds-center">
                                 <h4>Loading chaining configuration for <b>{this.state.node_text} ...</b></h4>
-                                <Spinner loading size="md" />
+                                <Spinner className="ds-margin-top-lg" loading size="md" />
                             </div>;
                     } else {
                         db_element =
@@ -1094,6 +1186,7 @@ export class Database extends React.Component {
                                 loadSuffixTree={this.loadSuffixTree}
                                 addNotification={this.addNotification}
                                 data={this.state[this.state.node_text]}
+                                enableTree={this.enableTree}
                                 reload={this.loadChainingLink}
                             />;
                     }
@@ -1110,7 +1203,7 @@ export class Database extends React.Component {
                 <div className="ds-container">
                     <div>
                         <div className="ds-tree">
-                            <div className="tree-view-container" id="db-tree"
+                            <div className={disabled} id="db-tree"
                                 style={treeViewContainerStyles}>
                                 <TreeView
                                     nodes={nodes}
@@ -1133,7 +1226,11 @@ export class Database extends React.Component {
                     showModal={this.state.showSuffixModal}
                     closeHandler={this.closeSuffixModal}
                     handleChange={this.handleChange}
+                    handleRadioChange={this.handleRadioChange}
                     saveHandler={this.createSuffix}
+                    noInit={this.state.noSuffixInit}
+                    addSuffix={this.state.createSuffixEntry}
+                    addSample={this.state.createSampleEntries}
                     error={this.state.errObj}
                 />
             </div>
@@ -1147,7 +1244,11 @@ class CreateSuffixModal extends React.Component {
             showModal,
             closeHandler,
             handleChange,
+            handleRadioChange,
             saveHandler,
+            noInit,
+            addSuffix,
+            addSample,
             error
         } = this.props;
 
@@ -1169,20 +1270,39 @@ class CreateSuffixModal extends React.Component {
                     </Modal.Header>
                     <Modal.Body>
                         <Form horizontal autoComplete="off">
-                            <div className="ds-inline">
-                                <div>
-                                    <label htmlFor="createSuffix" className="ds-config-label" title="Database Suffix DN (nsslapd-suffix)">
-                                        Suffix DN</label><input onChange={handleChange} className={error.createSuffix ? "ds-input-bad" : "ds-input"} type="text" id="createSuffix" size="40" />
-                                </div>
-                                <div>
-                                    <label htmlFor="createBeName" className="ds-config-label" title="Database backend name (nsslapd-backend)">
-                                        Backend Name</label><input onChange={handleChange} className={error.createBeName ? "ds-input-bad" : "ds-input"} type="text" id="createBeName" size="40" />
-                                </div>
-                                <div>
-                                    <p />
-                                    <input type="checkbox" className="ds-config-checkbox" id="createSampleEntries" onChange={handleChange} /><label
-                                        htmlFor="createSampleEntries" className="ds-label" title="Create the datbase with sample entries"> Create Sample Entries</label>
-                                </div>
+                            <Row title="Database suffix, like 'dc=example,dc=com'.  The suffix must be a valid LDAP Distiguished Name (DN)">
+                                <Col sm={3}>
+                                    <ControlLabel>Suffix DN</ControlLabel>
+                                </Col>
+                                <Col sm={5}>
+                                    <input onChange={handleChange} className={error.createSuffix ? "ds-input-bad" : "ds-input"} type="text" id="createSuffix" size="40" />
+                                </Col>
+                            </Row>
+                            <Row className="ds-margin-top" title="The name for the backend database, like 'userroot'.  The name can be a combination of alphanumeric characters, dashes (-), and underscores (_). No other characters are allowed, and the name must be unique across all backends.">
+                                <Col sm={3}>
+                                    <ControlLabel>Database Name</ControlLabel>
+                                </Col>
+                                <Col sm={5}>
+                                    <input onChange={handleChange} className={error.createBeName ? "ds-input-bad" : "ds-input"} type="text" id="createBeName" size="40" />
+                                </Col>
+                            </Row>
+                            <hr />
+                            <div>
+                                <Row className="ds-indent">
+                                    <Radio name="radioGroup" id="noSuffixInit" onChange={handleRadioChange} checked={noInit} inline>
+                                        Do Not Initialize Database
+                                    </Radio>
+                                </Row>
+                                <Row className="ds-indent">
+                                    <Radio name="radioGroup" id="createSuffixEntry" onChange={handleRadioChange} checked={addSuffix} inline>
+                                        Create The Top Suffix Entry
+                                    </Radio>
+                                </Row>
+                                <Row className="ds-indent">
+                                    <Radio name="radioGroup" id="createSampleEntries" onChange={handleRadioChange} checked={addSample} inline>
+                                        Add Sample Entries
+                                    </Radio>
+                                </Row>
                             </div>
                         </Form>
                     </Modal.Body>
@@ -1221,7 +1341,11 @@ CreateSuffixModal.propTypes = {
     showModal: PropTypes.bool,
     closeHandler: PropTypes.func,
     handleChange: PropTypes.func,
+    handleRadioChange: PropTypes.func,
     saveHandler: PropTypes.func,
+    noInit: PropTypes.bool,
+    addSuffix: PropTypes.bool,
+    addSample: PropTypes.bool,
     error: PropTypes.object,
 };
 
@@ -1229,6 +1353,10 @@ CreateSuffixModal.defaultProps = {
     showModal: false,
     closeHandler: noop,
     handleChange: noop,
+    handleRadioChange: noop,
     saveHandler: noop,
+    noInit: true,
+    addSuffix: false,
+    addSample: false,
     error: {},
 };
