@@ -3,6 +3,10 @@ import React from "react";
 import CustomCollapse from "../customCollapse.jsx";
 import { log_cmd } from "../tools.jsx";
 import {
+    Row,
+    Col,
+    ControlLabel,
+    Form,
     Spinner,
     noop
 } from "patternfly-react";
@@ -55,6 +59,10 @@ export class GlobalDatabaseConfig extends React.Component {
         this.save_db_config = this.save_db_config.bind(this);
     }
 
+    componentDidMount() {
+        this.props.enableTree();
+    }
+
     select_auto_cache (e) {
         this.setState({
             db_cache_auto: !this.state.db_cache_auto
@@ -210,8 +218,8 @@ export class GlobalDatabaseConfig extends React.Component {
             db_cache_form = <div id="auto-cache-form" className="ds-margin-left">
                 <div>
                     <label htmlFor="autosize" className="ds-config-label-xlrg"
-                        title="Enable database and entry cache auto-tuning using a percentage of the systems current resources (nsslapd-cache-autosize).">
-                        System Memory Percentage</label><input className="ds-input" type="text"
+                        title="Enable database and entry cache auto-tuning using a percentage of the system's current resources (nsslapd-cache-autosize).">
+                        Memory Percentage</label><input className="ds-input" type="text"
                         id="autosizee" size="10" onChange={this.handleChange}
                         value={this.state.autosize} />
                 </div>
@@ -228,7 +236,7 @@ export class GlobalDatabaseConfig extends React.Component {
             db_cache_form = <div id="manual-cache-form" className="ds-margin-left">
                 <label htmlFor="dbcachesize" className="ds-config-label-xlrg"
                     title="Specifies the database index cache size in bytes (nsslapd-dbcachesize).">
-                    Database Cache Size (bytes)</label><input className="ds-input" type="text"
+                    Database Cache Size</label><input className="ds-input" type="text"
                     id="dbcachesize" size="10" onChange={this.handleChange} value={this.state.dbcachesize} />
             </div>;
             db_auto_checked = false;
@@ -246,8 +254,8 @@ export class GlobalDatabaseConfig extends React.Component {
         } else {
             import_cache_form = <div id="manual-import-cache-form" className="ds-margin-left">
                 <label htmlFor="importcachesize" className="ds-config-label-xlrg"
-                    title="The size of the database cache used in the bulk import process. (nsslapd-import-cachesize).">
-                    Import Cache Size (bytes)</label><input className="ds-input" type="text" id="importcachesize"
+                    title="The size of the database cache in bytes used in the bulk import process. (nsslapd-import-cachesize).">
+                    Import Cache Size</label><input className="ds-input" type="text" id="importcachesize"
                     size="10" onChange={this.handleChange} value={this.state.importcachesize} />
             </div>;
             import_auto_checked = false;
@@ -256,58 +264,96 @@ export class GlobalDatabaseConfig extends React.Component {
         let spinner = "";
         if (this.state.loading) {
             spinner =
-                <div className="ds-loading-spinner ds-center">
-                    <p />
+                <div className="ds-loading-spinner ds-margin-top ds-center">
                     <h4>Loading global database configuration ...</h4>
-                    <Spinner loading size="md" />
+                    <Spinner className="ds-margin-top" loading size="md" />
                 </div>;
         }
 
         return (
-            <div className="container-fluid" id="db-global-page">
+            <div id="db-global-page">
                 {spinner}
                 <div className={this.state.loading ? 'ds-fadeout' : 'ds-fadein'}>
                     <h3 className="ds-config-header">Global Database Configuration</h3>
                     <hr />
-                    <div className="ds-container">
-                        <div className="ds-inline">
-                            <div>
-                                <label htmlFor="nsslapd-lookthrough-limit" className="ds-config-label"
-                                    title="The maximum number of entries that the Directory Server will check when examining candidate entries in response to a search request (nsslapd-lookthrough-limit).">
-                                    Database Look Though Limit</label><input id="looklimit" value={this.state.looklimit}
-                                    onChange={this.handleChange} className="ds-input" type="text" size="15" />
-                            </div>
-                            <div>
-                                <label htmlFor="nsslapd-idlistscanlimit" className="ds-config-label"
-                                    title="The number of entry IDs that are searched during a search operation (nsslapd-idlistscanlimit).">
-                                    ID List Scan Limit</label><input id="idscanlimit" value={this.state.idscanlimit}
-                                    onChange={this.handleChange} className="ds-input" type="text"size="15" />
-                            </div>
-                        </div>
-                        <div className="ds-divider" />
-                        <div className="ds-inline">
-                            <div>
-                                <label htmlFor="nsslapd-pagedlookthroughlimit" className="ds-config-label"
-                                    title="The maximum number of entries that the Directory Server will check when examining candidate entries for a search which uses the simple paged results control (nsslapd-pagedlookthroughlimit).">
-                                    Paged Search Look Through Limit</label><input id="pagelooklimit" value={this.state.pagelooklimit}
-                                    onChange={this.handleChange} className="ds-input" type="text" size="15" />
-                            </div>
-                            <div>
-                                <label htmlFor="nsslapd-pagedidlistscanlimit" className="ds-config-label"
-                                    title="The number of entry IDs that are searched, specifically, for a search operation using the simple paged results control (nsslapd-pagedidlistscanlimit).">
-                                    Paged Search ID List Scan Limit</label><input id="pagescanlimit"
-                                    value={this.state.pagescanlimit} onChange={this.handleChange}
-                                    className="ds-input" type="text" size="15" />
-                            </div>
-                            <div>
-                                <label htmlFor="nsslapd-rangelookthroughlimit" className="ds-config-label"
-                                    title="The maximum number of entries that the Directory Server will check when examining candidate entries in response to a range search request (nsslapd-rangelookthroughlimit).">
-                                    Range Search Look Through Limit</label><input id="rangelooklimit"
-                                    value={this.state.rangelooklimit} onChange={this.handleChange}
-                                    className="ds-input" type="text" size="15" />
-                            </div>
-                        </div>
-                    </div>
+                    <Form horizontal>
+                        <Row
+                            title="The maximum number of entries that the Directory Server will check when examining candidate entries in response to a search request (nsslapd-lookthrough-limit)."
+                            className="ds-margin-top"
+                        >
+                            <Col componentClass={ControlLabel} sm={5}>
+                                Database Look Though Limit
+                            </Col>
+                            <Col sm={4}>
+                                <input
+                                    id="looklimit"
+                                    value={this.state.looklimit}
+                                    onChange={this.handleChange} className="ds-input-auto" type="text"
+                                />
+                            </Col>
+                        </Row>
+                        <Row
+                            title="The number of entry IDs that are searched during a search operation (nsslapd-idlistscanlimit)."
+                            className="ds-margin-top"
+                        >
+                            <Col componentClass={ControlLabel} sm={5}>
+                                ID List Scan Limit
+                            </Col>
+                            <Col sm={4}>
+                                <input
+                                    id="idscanlimit"
+                                    value={this.state.idscanlimit}
+                                    onChange={this.handleChange} className="ds-input-auto" type="text"
+                                />
+                            </Col>
+                        </Row>
+                        <Row
+                            title="The maximum number of entries that the Directory Server will check when examining candidate entries for a search which uses the simple paged results control (nsslapd-pagedlookthroughlimit)."
+                            className="ds-margin-top"
+                        >
+                            <Col componentClass={ControlLabel} sm={5}>
+                                Paged Search Look Through Limit
+                            </Col>
+                            <Col sm={4}>
+                                <input
+                                    id="pagelooklimit"
+                                    value={this.state.pagelooklimit}
+                                    onChange={this.handleChange} className="ds-input-auto" type="text"
+                                />
+                            </Col>
+                        </Row>
+                        <Row
+                            title="The number of entry IDs that are searched, specifically, for a search operation using the simple paged results control (nsslapd-pagedidlistscanlimit)."
+                            className="ds-margin-top"
+                        >
+                            <Col componentClass={ControlLabel} sm={5}>
+                                Paged Search ID List Scan Limit
+                            </Col>
+                            <Col sm={4}>
+                                <input
+                                    id="pagescanlimit"
+                                    value={this.state.pagescanlimit}
+                                    onChange={this.handleChange} className="ds-input-auto" type="text"
+                                />
+                            </Col>
+                        </Row>
+                        <Row
+                            title="The maximum number of entries that the Directory Server will check when examining candidate entries in response to a range search request (nsslapd-rangelookthroughlimit)."
+                            className="ds-margin-top"
+                        >
+                            <Col componentClass={ControlLabel} sm={5}>
+                                Range Search Look Through Limit
+                            </Col>
+                            <Col sm={4}>
+                                <input
+                                    id="rangelooklimit"
+                                    value={this.state.rangelooklimit}
+                                    onChange={this.handleChange} className="ds-input-auto" type="text"
+                                />
+                            </Col>
+                        </Row>
+                    </Form>
+
                     <div className="ds-container">
                         <div>
                             <h4 className="ds-sub-header">Database Cache Settings</h4>
@@ -333,46 +379,54 @@ export class GlobalDatabaseConfig extends React.Component {
                         </div>
                     </div>
                     <CustomCollapse>
-                        <div className="ds-accordion-panel">
-                            <div className="ds-container">
-                                <div className="ds-inline">
-                                    <div>
-                                        <label htmlFor="nsslapd-db-logdirectory" className="ds-config-label"
-                                            title="Database Transaction Log Location (nsslapd-db-logdirectory).">
-                                            Transaction Logs Directory</label><input id="txnlogdir" value={this.state.txnlogdir}
-                                            onChange={this.handleChange} className="ds-input" type="text" size="25" />
-                                    </div>
-                                    <div>
-                                        <label htmlFor="nsslapd-db-home-directory" className="ds-config-label"
-                                        title="Location for database memory mapped files.  You must specify a subdirectory of a tempfs type filesystem (nsslapd-db-home-directory).">
-                                            Database Home Directory</label><input id="dbhomedir" value={this.state.dbhomedir}
-                                            onChange={this.handleChange} className="ds-input" type="text" size="25" />
-                                    </div>
-                                    <div>
-                                        <label htmlFor="nsslapd-db-locks" className="ds-config-label"
-                                            title="The number of database locks (nsslapd-db-locks).">
-                                            Database Locks</label><input id="dblocks" value={this.state.dblocks}
-                                            onChange={this.handleChange} className="ds-input" type="text" size="25" />
-                                    </div>
-                                    <div>
-                                        <label htmlFor="nsslapd-db-checkpoint-interval" className="ds-config-label"
-                                            title="Amount of time in seconds after which the Directory Server sends a checkpoint entry to the database transaction log (nsslapd-db-checkpoint-interval).">
-                                            Database Checkpoint Interval</label><input id="chxpoint" value={this.state.chxpoint}
-                                            onChange={this.handleChange} className="ds-input" type="text" size="25" />
-                                    </div>
-                                    <div>
-                                        <label htmlFor="nsslapd-db-compactdb-interval" className="ds-config-label"
-                                            title="The interval in seconds when the database is compacted (nsslapd-db-compactdb-interval).">
-                                            Database Compact Interval</label><input id="compactinterval" value={this.state.compactinterval}
-                                            onChange={this.handleChange}className="ds-input" type="text" size="25" />
-                                    </div>
-                                </div>
+                        <div className="ds-margin-top">
+                            <div className="ds-margin-left">
+                                <Form horizontal>
+                                    <Row className="ds-margin-top" title="Database Transaction Log Location (nsslapd-db-logdirectory).">
+                                        <Col componentClass={ControlLabel} sm={4}>
+                                            Transaction Logs Directory
+                                        </Col>
+                                        <Col sm={8}>
+                                            <input id="txnlogdir" value={this.state.txnlogdir} onChange={this.handleChange} className="ds-input-auto" type="text" />
+                                        </Col>
+                                    </Row>
+                                    <Row className="ds-margin-top" title="Location for database memory mapped files.  You must specify a subdirectory of a tempfs type filesystem (nsslapd-db-home-directory).">
+                                        <Col componentClass={ControlLabel} sm={4}>
+                                            Database Home Directory
+                                        </Col>
+                                        <Col sm={8}>
+                                            <input id="dbhomedir" value={this.state.dbhomedir} onChange={this.handleChange} className="ds-input-auto" type="text" />
+                                        </Col>
+                                    </Row>
+                                    <Row className="ds-margin-top" title="The number of database locks (nsslapd-db-locks).">
+                                        <Col componentClass={ControlLabel} sm={4}>
+                                            Database Locks
+                                        </Col>
+                                        <Col sm={8}>
+                                            <input id="dblocks" value={this.state.dblocks} onChange={this.handleChange} className="ds-input-auto" type="text" />
+                                        </Col>
+                                    </Row>
+                                    <Row className="ds-margin-top" title="Amount of time in seconds after which the Directory Server sends a checkpoint entry to the database transaction log (nsslapd-db-checkpoint-interval).">
+                                        <Col componentClass={ControlLabel} sm={4}>
+                                            Database Checkpoint Interval
+                                        </Col>
+                                        <Col sm={8}>
+                                            <input id="chxpoint" value={this.state.chxpoint} onChange={this.handleChange} className="ds-input-auto" type="text" />
+                                        </Col>
+                                    </Row>
+                                    <Row className="ds-margin-top" title="The interval in seconds when the database is compacted (nsslapd-db-compactdb-interval).">
+                                        <Col componentClass={ControlLabel} sm={4}>
+                                            Database Compact Interval
+                                        </Col>
+                                        <Col sm={8}>
+                                            <input id="compactinterval" value={this.state.compactinterval} onChange={this.handleChange} className="ds-input-auto" type="text" />
+                                        </Col>
+                                    </Row>
+                                </Form>
                             </div>
-                            <p />
                         </div>
                     </CustomCollapse>
-                    <p />
-                    <div className="ds-save-btn">
+                    <div className="ds-margin-top-lg">
                         <button className="btn btn-primary save-button"
                             onClick={this.save_db_config}>Save Configuration</button>
                     </div>
@@ -389,6 +443,7 @@ GlobalDatabaseConfig.propTypes = {
     addNotification: PropTypes.func,
     data: PropTypes.object,
     reload: PropTypes.func,
+    enableTree: PropTypes.func,
 };
 
 GlobalDatabaseConfig.defaultProps = {
@@ -396,4 +451,5 @@ GlobalDatabaseConfig.defaultProps = {
     addNotification: noop,
     data: {},
     reload: noop,
+    enableTree: noop,
 };
