@@ -2,8 +2,10 @@ import React from "react";
 import {
     Modal,
     Row,
+    Checkbox,
     Col,
     ControlLabel,
+    Radio,
     Icon,
     Button,
     Form,
@@ -44,7 +46,7 @@ class CreateLinkModal extends React.Component {
                         </Modal.Title>
                     </Modal.Header>
                     <Modal.Body>
-                        <Form horizontal autoComplete="off">
+                        <Form horizontal>
                             <div>
                                 <label htmlFor="createLinkSuffix" className="ds-config-label" title="The RDN of the link suffix">
                                     Link Sub-Suffix</label><input className={error.createLinkSuffix ? "ds-input-bad ds-input-right" : "ds-input ds-input-right"} onChange={handleChange} type="text" id="createLinkSuffix" size="12" /><b><font color="blue"> ,{suffix}</font></b>
@@ -110,8 +112,12 @@ class CreateSubSuffixModal extends React.Component {
             showModal,
             closeHandler,
             handleChange,
+            handleRadioChange,
             saveHandler,
             suffix,
+            noInit,
+            addSuffix,
+            addSample,
             error
         } = this.props;
 
@@ -133,7 +139,7 @@ class CreateSubSuffixModal extends React.Component {
                     </Modal.Header>
                     <Modal.Body>
                         <Form horizontal autoComplete="off">
-                            <Row title="Database Suffix DN (nsslapd-suffix)">
+                            <Row title="Database suffix, like 'dc=example,dc=com'.  The suffix must be a valid LDAP Distiguished Name (DN)">
                                 <Col sm={3}>
                                     <ControlLabel>Sub-Suffix DN</ControlLabel>
                                 </Col>
@@ -149,10 +155,9 @@ class CreateSubSuffixModal extends React.Component {
                                     <ControlLabel><b><font color="blue">,{suffix}</font></b></ControlLabel>
                                 </Col>
                             </Row>
-                            <p />
-                            <Row title="Database backend name (nsslapd-backend)">
+                            <Row className="ds-margin-top" title="The name for the backend database, like 'userroot'.  The name can be a combination of alphanumeric characters, dashes (-), and underscores (_). No other characters are allowed, and the name must be unique across all backends.">
                                 <Col sm={3}>
-                                    <ControlLabel>Backend Name</ControlLabel>
+                                    <ControlLabel>Database Name</ControlLabel>
                                 </Col>
                                 <Col sm={9}>
                                     <FormControl
@@ -163,6 +168,24 @@ class CreateSubSuffixModal extends React.Component {
                                     />
                                 </Col>
                             </Row>
+                            <hr />
+                            <div>
+                                <Row className="ds-indent">
+                                    <Radio name="radioGroup" id="noSuffixInit" onChange={handleRadioChange} checked={noInit} inline>
+                                        Do Not Initialize Database
+                                    </Radio>
+                                </Row>
+                                <Row className="ds-indent">
+                                    <Radio name="radioGroup" id="createSuffixEntry" onChange={handleRadioChange} checked={addSuffix} inline>
+                                        Create The Top Sub-Suffix Entry
+                                    </Radio>
+                                </Row>
+                                <Row className="ds-indent">
+                                    <Radio name="radioGroup" id="createSampleEntries" onChange={handleRadioChange} checked={addSample} inline>
+                                        Add Sample Entries
+                                    </Radio>
+                                </Row>
+                            </div>
                         </Form>
                     </Modal.Body>
                     <Modal.Footer>
@@ -200,7 +223,7 @@ class ExportModal extends React.Component {
         if (spinning) {
             spinner =
                 <Row>
-                    <div className="ds-modal-spinner">
+                    <div className="ds-margin-top-lg ds-modal-spinner">
                         <Spinner loading inline size="lg" />Exporting database... <font size="1">(You can safely close this window)</font>
                     </div>
                 </Row>;
@@ -237,7 +260,17 @@ class ExportModal extends React.Component {
                                     />
                                 </Col>
                             </Row>
-                            <p />
+                            <Row className="ds-margin-top-xlg">
+                                <Col sm={12} className="ds-margin-left">
+                                    <Checkbox
+                                        id="includeReplData"
+                                        onChange={handleChange}
+                                        title="Include the replication metadata needed to restore or initialize another replica."
+                                    >
+                                        Include Replication Data
+                                    </Checkbox>
+                                </Col>
+                            </Row>
                             {spinner}
                         </Form>
                     </Modal.Body>
@@ -279,8 +312,7 @@ class ImportModal extends React.Component {
         if (spinning) {
             spinner =
                 <Row>
-                    <div className="ds-modal-spinner">
-                        <p />
+                    <div className="ds-margin-top-lg ds-modal-spinner">
                         <Spinner loading inline size="lg" />Importing LDIF file... <font size="1">(You can safely close this window)</font>
                     </div>
                 </Row>;
@@ -308,7 +340,6 @@ class ImportModal extends React.Component {
                         </Modal.Title>
                     </Modal.Header>
                     <Modal.Body>
-                        <p />
                         <LDIFTable
                             rows={suffixRows}
                             confirmImport={this.props.showConfirmImport}
@@ -335,7 +366,6 @@ class ImportModal extends React.Component {
                                     </Button>
                                 </Col>
                             </Row>
-                            <p />
                             {spinner}
                         </Form>
                     </Modal.Body>
