@@ -8,6 +8,7 @@
 # --- END COPYRIGHT BLOCK ---
 
 import os
+import logging
 import sys
 import shutil
 import pwd
@@ -32,6 +33,7 @@ from lib389.utils import (
     assert_c,
     is_a_dn,
     ensure_str,
+    ensure_list_str,
     normalizeDN,
     socket_check_open,
     selinux_label_port,
@@ -40,6 +42,10 @@ from lib389.utils import (
 
 ds_paths = Paths()
 
+# We need this to decide if we should remove after a failed install - useful
+# for tests ONLY which is why it's the env flag still.
+DEBUGGING = os.getenv('DEBUGGING', default=False)
+
 
 def get_port(port, default_port, secure=False):
     # Get the port number for the interactive installer and validate it
@@ -238,8 +244,11 @@ class SetupDs(object):
         print('===========================================')
 
         # Set the defaults
-        general = {'config_version': 2, 'full_machine_name': socket.getfqdn(),
-                   'strict_host_checking': True, 'selinux': True, 'systemd': ds_paths.with_systemd,
+        general = {'config_version': 2,
+                   'full_machine_name': socket.getfqdn(),
+                   'strict_host_checking': False,
+                   'selinux': True,
+                   'systemd': ds_paths.with_systemd,
                    'defaults': '999999999', 'start': True}
 
         slapd = {'self_sign_cert_valid_months': 24,
@@ -283,24 +292,6 @@ class SetupDs(object):
         if val != "":
             general['full_machine_name'] = val
 
-        # Strict host name checking
-        msg = ("\nUse strict hostname verification (set to \"no\" if using GSSAPI behind a load balancer) [yes]: ")
-        while 1:
-            val = input(msg).rstrip().lower()
-            if val != "":
-                if val == "no" or val == "n":
-                    slapd['strict_host_checking'] = False
-                    break
-                if val == "yes" or val == "y":
-                    # Use default
-                    break
-
-                # Unknown value
-                print ("Value \"{}\" is invalid, please use \"yes\" or \"no\"".format(val))
-                continue
-            else:
-                break
-
         # Instance name - adjust defaults once set
         while 1:
             slapd['instance_name'] = general['full_machine_name'].split('.', 1)[0]
@@ -407,6 +398,11 @@ class SetupDs(object):
                 print('Password can not be empty')
                 continue
 
+            if len(rootpw1) < 8:
+                print('Password must be at least 8 characters long')
+                continue
+
+
             rootpw2 = getpass.getpass('Confirm the Directory Manager Password: ').rstrip()
             if rootpw1 != rootpw2:
                 print('Passwords do not match')
@@ -581,6 +577,9 @@ class SetupDs(object):
         assert_c(is_a_dn(slapd['root_dn']), "root_dn in section [slapd] is not a well formed LDAP DN")
         assert_c(slapd['root_password'] is not None and slapd['root_password'] != '',
                  "Configuration attribute 'root_password' in section [slapd] not found")
+        if len(slapd['root_password']) < 8:
+            raise ValueError("root_password must be at least 8 characters long")
+
         # Check if pre-hashed or not.
         # !!!!!!!!!!!!!!
 
@@ -635,7 +634,9 @@ class SetupDs(object):
         Actually does the setup. this is what you want to call as an api.
         """
 
-        self.log.info("\nStarting installation...")
+        self.log.debug("START: Starting installation...")
+        if not self.verbose:
+            self.log.info("Starting installation...")
 
         # Check we have privs to run
         self.log.debug("READY: Preparing installation for %s...", slapd['instance_name'])
@@ -653,8 +654,11 @@ class SetupDs(object):
             try:
                 self._install_ds(general, slapd, backends)
             except ValueError as e:
-                self.log.fatal("Error: " + str(e) + ", removing incomplete installation...")
-                self._remove_failed_install(slapd['instance_name'])
+                if DEBUGGING is False:
+                    self.log.fatal("Error: " + str(e) + ", removing incomplete installation...")
+                    self._remove_failed_install(slapd['instance_name'])
+                else:
+                    self.log.fatal("Error: " + str(e) + ", preserving incomplete installation for analysis...")
                 raise ValueError("Instance creation failed!")
 
             # Call the child api to do anything it needs.
@@ -662,6 +666,7 @@ class SetupDs(object):
         self.log.debug("FINISH: Completed installation for %s", slapd['instance_name'])
         if not self.verbose:
             self.log.info("Completed installation for %s", slapd['instance_name'])
+
         return True
 
     def _install_ds(self, general, slapd, backends):
@@ -777,9 +782,12 @@ class SetupDs(object):
         # If we are on the correct platform settings, systemd
         if general['systemd']:
             # Should create the symlink we need, but without starting it.
-            subprocess.check_call(["systemctl",
-                                   "enable",
-                                   "dirsrv@%s" % slapd['instance_name']])
+            result = subprocess.run(["systemctl", "enable", "dirsrv@%s" % slapd['instance_name']],
+                                    stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            args = ' '.join(ensure_list_str(result.args))
+            stdout = ensure_str(result.stdout)
+            stderr = ensure_str(result.stderr)
+            self.log.debug(f"CMD: {args} ; STDOUT: {stdout} ; STDERR: {stderr}")
 
             # Setup tmpfiles_d
             tmpfile_d = ds_paths.tmpfiles_d + "/dirsrv-" + slapd['instance_name'] + ".conf"
@@ -794,7 +802,6 @@ class SetupDs(object):
 
         # Bind sockets to our type?
 
-
         # Create certdb in sysconfidir
         self.log.debug("ACTION: Creating certificate database is %s", slapd['cert_dir'])
 
@@ -804,8 +811,8 @@ class SetupDs(object):
         # Should I move this import? I think this prevents some recursion
         from lib389 import DirSrv
         ds_instance = DirSrv(self.verbose)
-        if self.containerised:
-            ds_instance.systemd = general['systemd']
+        # if self.containerised:
+        #     ds_instance.systemd = general['systemd']
         args = {
             SER_PORT: slapd['port'],
             SER_SERVERID_PROP: slapd['instance_name'],
@@ -819,7 +826,7 @@ class SetupDs(object):
         assert_c(ds_instance.exists(), "Instance failed to install, does not exist when expected")
 
         # Create a certificate database.
-        tlsdb = NssSsl(dbpath=slapd['cert_dir'])
+        tlsdb = NssSsl(dirsrv=ds_instance, dbpath=slapd['cert_dir'])
         if not tlsdb._db_exists():
             tlsdb.reinit()
 
